==> win32_Release_v3.2.6_r375.zip: data/scripts/gs/process.lua <==
amta-b  Y0]-B0DlK,_qviNgm̹񽽶Ѣ▓֤Šӧ̾ţָۧش񝜜ڼȼΧɮ3G/J$.'.i:{q|#B&BqEɧꏹʥSJMmjJ#S2[)ZӼ*)aa ,ݸֲLggnF3A-!@2U&
*L>Q<qyF3V#FoeB~zxws}PQyPZS+9puR@m%'&;8H{	S`amcHƥѵ۴ihl/@5[/J8O^zssw(X*E#J&Cu}OoRrtdHhnӌ337hrofQͨɽnlZeeb`b
yC.K#zLvwvVTűâ̿ټΑlmli nNMvrsg|\_.(/-J/[q,-^Ҿ''B&Od

#ʕ
5hh^:=bddg8N|JdE!N \٪޿˾__:ǵаڨˮæȼ11ڭ̾xyxnCcbȪӿ=-ɬۺȬce3ؖ倠ʹܽϬ씖2,^vzy}v{v)WʭlnB״en^'&'S<I;_Ѷӧ]\uuxQ7UTP<Y8_*O<KKI>Q>Z%(߀雲MJfF%D(D&G$OA_6Pw##mhNɻɦ滺32Ϯ'±mqs(]/Cf{z.G*OmE`iH!Gg榦]Mo?櫫FDEm*y)ȻˤʹǦϣƢy]~(sϣ$\\~>3 %!S6[4B'o^WrJo¬)8BghHo$,fBA"C-N+GaQZ涛]_1X4PKI+Y<]688ָS{,ܻުǵڷ޻ר(*F)N!	}pپۯ㎦ㄣ+.FFD7_>N+a*fjàϣ̾"uzM傢4Q}rr1zNi&^[roEiI6յǎkoGӷ}~t}LDE=CC31,-/B-Y-Bm>;:Q5(of730FBeL~dF(!XL<,s&䰱6wjr~
**+*G"F'ֶ/vGǰٷggIIm__[/,__s{T

T O~cH[[g'&-@%V%D#F	o;S6r#37жϫʳհҡȼ<$,115Y8V1D%B<x|R&Ip9QPw7<8O.\isC8_;8ɪ˥rDk枞6?>|||k'"'S:W2A5T9	Y[tT^Ѥ԰ѥ"?-קռҦhmjPb@`N`@4[tv_v|N{	,/?"̴&&Ϳߖnk00l-ȼ2'%	iiR)@4cmE嘾aebrRq
Gv:ʚ
	kjl	1=<.,æèиݳϽ67@!S VT&Rq9vwp8XXj'-)J8A2F'K+x\衆1߬77aKhWuh"_{;vt=  5֭h&S>nL?2W>Hb`flelLKځ赙U3̈́듻
cN 8ð߭0)60qgp/M4'' D!G.@)]4[5¿PvZz^juwPڴѦtXsR $·ŷҼȗ##"yMcɀ'ڿھϣ\V=`2^&
*	9Q_|CBNϔ#"ˢϢ׹Ф݂	9Ĩ99楤Ի\hJBdHىQR&x2{s{vi}[
;U1U{pP>Q%,$8~v-#ccbBiIx}Q}xZq-ɠIwPC"<;,cDPZx8&LG?$pmlB,.aGv[EiYi#ӂޏ$
^̭۾̭蓵ع=߆aֹݦфkhB+H#ma$>&,53Vɖb.AGwMI.\=; *ʦ13CHm
3KHayxKM>5P.~UrpWJf.	\uv_[Z6w[gd^vMFk>9>bN><NdN,##vjkc"®~~R**'+ܸffI1<LBnjk{<W^rR]p|8JIxZ>T| l_v60ŵ|LLzNO6rp[Y## "rZ66YO_ݩGEfPêϟģ..FEhRBs#(ZNbe@BeZ]nELBvwjǿŌnnDlm[bJ?w#ksZ9<<U_[2\*C7R
=m?:qX`a]~s Twϼd+˟ߘ\㲻03Jw8^cR-	!:Yq5}QEGkKC44``MfVTdq0ٵн#gCCzVca3oiNgGӅ 	/?gr4ge	|8hb֢۫/mkEm))
yZrvIC/F#M9lkK2B'S[>L:_-ͮج}}Sx454v$nmJ%raCqT|ܽӧΣ¶§ټĴNJIgpx6ҾѾοofF{\45"#
%./ݥyy[wl)QsFʊzu7X7Xq[&/\9	R@l|^vQCCm-qH4\#"	%%'fc`vA/KiA6ĒzW#,HWPryDfʁKU)OO娅Z~Ruq`MA
!abN4}_[.9Tw֪ԐDRidCUV	9}^vbcAAA!%u]hhBt|軙ksQ|^:
L;^3654W8V	l5eLhjklgE4-/XzuPktP%9Hjй߫Ĵ6\?8$4wu^10<P(<e@vSb].2ƪ%!<5<43t\~xW鹹#oд}" ڰն±̥w/^Xv^P|\1a tdզ츸HZ>;ODaUd}^FsvvpP?kLǯ윢ˢQPp%
]+x|{A-H&'9)Fpy׸blB$K9T5AiKn]x)%ԽxiJZ*RTXsxPyP|\zrv+Yq׌Ӌ޿=R<̥ˢѹܸ ,;-@`DUUWp\|g%	)N={rg;Im,#Z2[ i?o=jg#
,dgMa` 3۴S'B&,((`jMl eó*ݼ-,-
&7H{V{[>
&~~C~^bHj
 Ӻɟxmdm[[?w3ig]\	{X􌪮˥KkV}E@μȼ~WTfϳ1}ZvfOv5V1gON-B0Tӧ786;{olzA4Fo#&hv_v1/T,@99moIEjZ30aE<Xt@5ϟ፦掬U&dm@mbTIJcUkP/wF""LEe}޸7ힰ溱>6MLsX= 	)YU\xX#~uPahK恥
rHDWsfBꊍT"PՙIl0NKHB`dK?OM75;tS?)[uVjFdx2邈ϗifCK0:3
dXre"* 7&llAڲڕ2#Zw]qYy^n򲵝ޢ:lhK'33=諉w]$''.P*$LBm
+!+0DA!-gn@kjCc~F{~P
1nGM92Y2eGd,%,%[[q'jKbrOw~:ߺ&}QIH//蕉wֲ8<̐hLEtg
y6X}z"cEmFšnr.$+18o;:=jw?V2(2?kJhʕ~w~w҂®?13z6X1%mB&"  U[bOMaOfhcq`^
 O/.ǃk[<=I(ZyIHhaAgpqXED47&'ˍQٽ߭Ȯ۵Rp]!!uR[tlu%+#P~~};o8'=yF@uQ9EM1xرW+a_hѐbG'-򾿛=% % `PPphMcSh
yYptͤ<tW+&+7۲<<⭝MmodA$w<4RsB:S T'(d?״&$j~GnfjE
&
3}|YCM)ޮpS;i%lU\rG\h(*FRcR9!qBb	1eBSf
 |uX\E{BCA@PWWV26ɡħ=RyZyƣP^~\(!DȬuwS׳>ABKBK"Q}SefV(xB4/4>Nb	{Hl,-00۰<,2a`gL_̨N|V "ڎnALDcGoA#_PG1MkAmnL̲4YrV^{7//kfO#Ma?q0-ޭ%=h{NLmdv/
*	hL%iJrdNQvb)\ 7_WuYKMf6B#WZ2'EHHQwvU),ggRن\|[?1m:~?1d{V07ܤ.hNAk)8[x|TԆ_{5a`뇧HҶϪ$$\O<KaxjCe겢v Ƿs|鲑NOj_zR0<< )(uQ
!=>(''!R\5[=BVx[8?=pӷ7^0V~J"7)Ą冤I=pfu9YXR{wN^Py&+<I=' >uoA0&j98Q`LX9PmՌ־g^JvRW/22
9<K*X|`OhxIup[ף-06Smd;M	+ilFdbI*bac^~Y0^|\URS5\0\yxZ^{_{()B5T&594X%LF"ҶN:<bcpobMBAb~łQfeXx_1^*vcJ2ǯϮHd?#!f0T{z@adQrBfg()L%{6m1"J%䤄q@HIin>15&ѡ=)zJ	}T(5Is_?9Y13
_^~iinJF4S;ϯf"*fnϻ]w]::"$+SU6²ۿ1Ϭʩܨҍ7%)d&/-Wh~WQscu~ :>NHZoI\vB``H`;aIHNlIB|r; =aaeG3V%Q 
=&D"E$I=Z;V3@bvwtoMB@n
b-UQ}v6
&t2BFe4wT=5|2m=o g5p#pZsv^+182gۣU"'kVfh@"2ܴ'م tH<,, ҊWS!D #Ye
#Y*<So#!15YUwکlLM,06FUs4=S<RrqwzX섑}(bcOl9?ƷKQ)#1QSw(H9JhW-=9 32ű/LL87VD艛$	/'

==> win32_Release_v4.0.2_r955.zip: data/scripts/gs/process.lua <==
amtab  Y0]-B0DlK,_qviNgm̹񽽶Ѣ▓֤Šӧ̾ţָۧش񝜜ڼȼΧɮ3G/J$.'.i:{q|#B&BqEɧꏹʥSJMmjJ#S2[)ZӼ*)aa ,ݸֲLggnF3A-!@2U&
*L>Q<qyF3V#FoeB~zxws}PQyPZS+9puR@m%'&;8H{	S`amcHƥѵ۴ihl/@5[/J8O^zssw(X*E#J&Cu}OoRrtdHhnӌ337hrofQͨɽnlZeeb`b
yC.K#zLvwvVTűâ̿ټΑlmli nNMvrsg|\_.(/-J/[q,-^Ҿ''B&Od

#ʕ
5hh^:=bddg8N|JdE!N \٪޿˾__:ǵаڨˮæȼ11ڭ̾xyxnCcbȪӿ=-ɬۺȬce3ؖ倠ʹܽϬ씖2,^vzy}v{v)WʭlnB״en^'&'S<I;_Ѷӧ]\uuxQ7UTP<Y8_*O<KKI>Q>Z%(߀雲MJfF%D(D&G$OA_6Pw##mhNɻɦ滺32Ϯ'±mqs(]/Cf{z.G*OmE`iH!Gg榦]Mo?櫫FDEm*y)ȻˤʹǦϣƢy]~(sϣ$\\~>3 %!S6[4B'o^WrJo¬)8BghHo$,fBA"C-N+GaQZ涛]_1X4PKI+Y<]688ָS{,ܻުǵڷ޻ר(*F)N!	}pپۯ㎦ㄣ+.FFD7_>N+a*fjàϣ̾"uzM傢4Q}rr1zNi&^[roEiI6յǎkoGӷ}~t}LDE=CC31,-/B-Y-Bm>;:Q5(of730FBeL~dF(!XL<,s&䰱6wjr~
**+*G"F'ֶ/vGǰٷggIIm__[/,__s{T

T O~cH[[g'&-@%V%D#F	o;S6r#37жϫʳհҡȼ<$,115Y8V1D%B<x|R&Ip9QPw7<8O.\isC8_;8ɪ˥rDk枞6?>|||k'"'S:W2A5T9	Y[tT^Ѥ԰ѥ"?-קռҦhmjPb@`N`@4[tv_v|N{	,/?"̴&&Ϳߖnk00l-ȼ2'%	iiR)@4cmE嘾aebrRq
Gv:ʚ
	kjl	1=<.,æèиݳϽ67@!S VT&Rq9vwp8XXj'-)J8A2F'K+x\衆1߬77aKhWuh"_{;vt=  5֭h&S>nL?2W>Hb`flelLKځ赙U3̈́듻
cN 8ð߭0)60qgp/M4'' D!G.@)]4[5¿PvZz^juwPڴѦtXsR $·ŷҼȗ##"yMcɀ'ڿھϣ\V=`2^&
*	9Q_|CBNϔ#"ˢϢ׹Ф݂	9Ĩ99楤Ի\hJBdHىQR&x2{s{vi}[
;U1U{pP>Q%,$8~v-#ccbBiIx}Q}xZq-ɠIwPC"<;,cDPZx8&LG?$pmlB,.aGv[EiYi#ӂޏ$
^̭۾̭蓵ع=߆aֹݦфkhB+H#ma$>&,53Vɖb.AGwMI.\=; *ʦ13CHm
3KHayxKM>5P.~UrpWJf.	\uv_[Z6w[gd^vMFk>9>bN><NdN,##vjkc"®~~R**'+ܸffI1<LBnjk{<W^rR]p|8JIxZ>T| l_v60ŵ|LLzNO6rp[Y## "rZ66YO_ݩGEfPêϟģ..FEhRBs#(ZNbe@BeZ]nELBvwjǿŌnnDlm[bJ?w#ksZ9<<U_[2\*C7R
=m?:qX`a]~s Twϼd+˟ߘ\㲻03Jw8^cR-	!:Yq5}QEGkKC44``MfVTdq0ٵн#gCCzVca3oiNgGӅ 	/?gr4ge	|8hb֢۫/mkEm))
yZrvIC/F#M9lkK2B'S[>L:_-ͮج}}Sx454v$nmJ%raCqT|ܽӧΣ¶§ټĴNJIgpx6ҾѾοofF{\45"#
%./ݥyy[wl)QsFʊzu7X7Xq[&/\9	R@l|^vQCCm-qH4\#"	%%'fc`vA/KiA6ĒzW#,HWPryDfʁKU)OO娅Z~Ruq`MA
!abN4}_[.9Tw֪ԐDRidCUV	9}^vbcAAA!%u]hhBt|軙ksQ|^:
L;^3654W8V	l5eLhjklgE4-/XzuPktP%9Hjй߫Ĵ6\?8$4wu^10<P(<e@vSb].2ƪ%!<5<43t\~xW鹹#oд}" ڰն±̥w/^Xv^P|\1a tdզ츸HZ>;ODaUd}^FsvvpP?kLǯ윢ˢQPp%
]+x|{A-H&'9)Fpy׸blB$K9T5AiKn]x)%ԽxiJZ*RTXsxPyP|\zrv+Yq׌Ӌ޿=R<̥ˢѹܸ ,;-@`DUUWp\|g%	)N={rg;Im,#Z2[ i?o=jg#
,dgMa` 3۴S'B&,((`jMl eó*ݼ-,-
&7H{V{[>
&~~C~^bHj
 Ӻɟxmdm[[?w3ig]\	{X􌪮˥KkV}E@μȼ~WTfϳ1}ZvfOv5V1gON-B0Tӧ786;{olzA4Fo#&hv_v1/T,@99moIEjZ30aE<Xt@5ϟ፦掬U&dm@mbTIJcUkP/wF""LEe}޸7ힰ溱>6MLsX= 	)YU\xX#~uPahK恥
rHDWsfBꊍT"PՙIl0NKHB`dK?OM75;tS?)[uVjFdx2邈ϗifCK0:3
dXre"* 7&llAڲڕ2#Zw]qYy^n򲵝ޢ:lhK'33=諉w]$''.P*$LBm
+!+0DA!-gn@kjCc~F{~P
1nGM92Y2eGd,%,%[[q'jKbrOw~:ߺ&}QIH//蕉wֲ8<̐hLEtg
y6X}z"cEmFšnr.$+18o;:=jw?V2(2?kJhʕ~w~w҂®?13z6X1%mB&"  U[bOMaOfhcq`^
 O/.ǃk[<=I(ZyIHhaAgpqXED47&'ˍQٽ߭Ȯ۵Rp]!!uR[tlu%+#P~~};o8'=yF@uQ9EM1xرW+a_hѐbG'-򾿛=% % `PPphMcSh
yYptͤ<tW+&+7۲<<⭝MmodA$w<4RsB:S T'(d?״&$j~GnfjE
&
3}|YCM)ޮpS;i%lU\rG\h(*FRcR9!qBb	1eBSf
 |uX\E{BCA@PWWV26ɡħ=RyZyƣP^~\(!DȬuwS׳>ABKBK"Q}SefV(xB4/4>Nb	{Hl,-00۰<,2a`gL_̨N|V "ڎnALDcGoA#_PG1MkAmnL̲4YrV^{7//kfO#Ma?q0-ޭ%=h{NLmdv/
*	hL%iJrdNQvb)\ 7_WuYKMf6B#WZ2'EHHQwvU),ggRن\|[?1m:~?1d{V07ܤ.hNAk)8[x|TԆ_{5a`뇧HҶϪ$$\O<KaxjCe겢v Ƿs|鲑NOj_zR0<< )(uQ
!=>(''!R\5[=BVx[8?=pӷ7^0V~J"7)Ą冤I=pfu9YXR{wN^Py&+<I=' >uoA0&j98Q`LX9PmՌ־g^JvRW/22
9<K*X|`OhxIup[ף-06Smd;M	+ilFdbI*bac^~Y0^|\URS5\0\yxZ^{_{()B5T&594X%LF"ҶN:<bcpobMBAb~łQfeXx_1^*vcJ2ǯϮHd?#!f0T{z@adQrBfg()L%{6m1"J%䤄q@HIin>15&ѡ=)zJ	}T(5Is_?9Y13
_^~iinJF4S;ϯf"*fnϻ]w]::"$+SU6²ۿ1Ϭʩܨҍ7%)d&/-Wh~WQscu~ :>NHZoI\vB``H`;aIHNlIB|r; =aaeG3V%Q 
=&D"E$I=Z;V3@bvwtoMB@n
b-UQ}v6
&t2BFe4wT=5|2m=o g5p#pZsv^+182gۣU"'kVfh@"2ܴ'م tH<,, ҊWS!D #Ye
#Y*<So#!15YUwکlLM,;ί̩   |~T 	mJlT۵ڴ]}}YEmgO~,d	"y?
.ZH[l~z[%=*RmIㄠ wuWZpXghDML	;_M1:4 ,zƪ̢̩ǣ
